<?php
/**
 * The template for displaying comments and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Walser
 * @since 1.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">

	<!-- Check if there are comments -->
	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				$comments_number = get_comments_number();
			if ( 1 === $comments_number ) {
				/* translators: %s: post title */
				printf( esc_html_x( '1 comment on &ldquo;%s&rdquo;', 'comments title', 'walser' ), get_the_title() );
			} else {
				printf(
					/* translators: 1: number of comments, 2: post title */
					esc_html( _nx(
						'%1$s comment on &ldquo;%2$s&rdquo;',
						'%1$s comments on &ldquo;%2$s&rdquo;',
						$comments_number,
						'comments title',
						'walser'
					)
					),
					esc_html( number_format_i18n( $comments_number ) ),
					get_the_title()
				);
			}
			?>
		</h2>

		<!-- Comments list -->
		<ol class="comment-list">
			<?php
			wp_list_comments( array(
				'style'       => 'ol',
				'avatar_size' => 80,
				'type' 		  => 'all',
				'format'      => 'html5',
				'callback'    => 'walser_comment',
			) );
			?>
		</ol>

		<!-- Comments navigation -->
		<div class="navigation">
			<div class="alignleft"><?php previous_comments_link( esc_html__( '&laquo; Older Comments', 'walser' ) ); ?></div>
			<div class="alignright"><?php next_comments_link( esc_html__( 'Newer Comments &raquo;', 'walser' ) ); ?></div>
		</div>

	<?php endif; ?>

	<?php
	// If there are comments, but commenting is closed, let's leave some note.
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
	<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'walser' ); ?></p>
	<?php endif; ?>

	<?php // Comment form.
		comment_form( array(
			'title_reply_before' => '<h2 id="reply-title" class="comment-reply-title">',
			'title_reply_after'  => '</h2>',
		) );
	?>

</div>