<?php
/**
 * Walser functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Walser
 * @since 1.0.0
 */

if ( ! function_exists( 'walser_setup' ) ) :

	/**
	 * Setup theme fot its work.
	 */
	function walser_setup() {

		/**
		 * Make theme available for translation.
		 */
		load_theme_textdomain( 'walser', get_template_directory() . '/languages' );

		/**
		 * Add default posts and comments RSS feed links to head.
		 */
		add_theme_support( 'automatic-feed-links' );

		/**
		 * Let WordPress manage the document title.
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Enable support for Post Thumbnails.
		 */
		add_theme_support( 'post-thumbnails' );

		add_image_size( 'walser-max-thumb', 1040, 510, true );
		add_image_size( 'walser-min-thumb', 480, 510, true );

		/**
		 * Registers an editor stylesheet for the theme.
		 */
		function walser_add_editor_styles() {
			add_editor_style( 'css/custom-editor-style.css' );
		}
		add_action( 'admin_init', 'walser_add_editor_styles' );

		/**
		 * Enable support for valid HTML5 in Comment and Search Forms.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
			)
		);

		/**
		 * Enable support for Post Formats.
		 */
		add_theme_support(
			'post-formats',
			array(
				'aside',
				'audio',
				'chat',
				'gallery',
				'image',
				'link',
				'quote',
				'status',
				'video',
			)
		);

		/**
		 * This theme uses wp_nav_menu() in one location.
		 */
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Menu', 'walser' ),
			)
		);

		/**
		 * Adds class to all menu items.
		 */
		function walser_add_class_to_all_menu_items( $classes ) {
			$classes['class'] = 'nav-item';

			return $classes;
		}
		add_filter( 'nav_menu_css_class', 'walser_add_class_to_all_menu_items' );

		/**
		 * Adds class to all menu links.
		 */
		function walser_add_class_to_all_menu_anchors( $atts ) {
			$atts['class'] = 'nav-link';

			return $atts;
		}
		add_filter( 'nav_menu_link_attributes', 'walser_add_class_to_all_menu_anchors' );

		/**
		 * Enable support for custom logo.
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 70,
				'width'       => 230,
				'flex-height' => true,
			)
		);

		/**
		 * Indicate widget sidebars can use selective refresh in the Customizer.
		 */
		add_theme_support( 'customize-selective-refresh-widgets' );

	}
endif;
add_action( 'after_setup_theme', 'walser_setup' );

/**
 * Set the content width based on the theme's design and stylesheet.
 */
function walser_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'walser_content_width', 680 );
}
add_action( 'after_setup_theme', 'walser_content_width', 0 );

/**
 * Indicate widget sidebars can use selective refresh in the Customizer.
 */
function walser_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Main Sidebar', 'walser' ),
		'id'            => 'sidebar-main',
		'description'   => esc_html__( 'Adds widgets to Main Sidebar.', 'walser' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar 1', 'walser' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Appears at the bottom of the site. Adds widgets to the 1st (left) footer sidebar.', 'walser' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar 2', 'walser' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Appears at the bottom of the site. Adds widgets to the 2nd (center) footer sidebar.', 'walser' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar 3', 'walser' ),
		'id'            => 'sidebar-3',
		'description'   => esc_html__( 'Appears at the bottom of the site. Adds widgets to the 3rd (right) footer sidebar.', 'walser' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Copyright', 'walser' ),
		'id'            => 'sidebar-copy',
		'description'   => esc_html__( 'Adds copyright credits at the bottom of the site.', 'walser' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

}
add_action( 'widgets_init', 'walser_widgets_init' );

/**
 * Enqueues styles and scripts.
 */
function walser_theme_styles_scripts() {

	// Styles.
	wp_enqueue_style( 'walser-style', get_stylesheet_uri() );

	wp_enqueue_style( 'walser-normalize', get_template_directory_uri() . '/css/normalize.css', array(), '8.0.0' );

	wp_enqueue_style( 'walser-swipebox', get_template_directory_uri() . '/css/swipebox.css', array(), '1.4.4' );

	// Fonts.
	wp_enqueue_style( 'roboto', get_template_directory_uri() . '/fonts/roboto.css', array(), '1.0' );

	wp_enqueue_style( 'awesome', get_template_directory_uri() . '/fonts/awesome/css/awesome.css', array(), '5.0' );

	// Scripts.
	wp_enqueue_script( 'walser-modernizr', get_template_directory_uri() . '/js/modernizr-2.5.3.js', array( 'jquery' ), '2.5.3', true );

	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/html5shiv.js', array(), '3.7.3', true );

	wp_enqueue_script( 'skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array( 'jquery' ), '1.0', true );

	wp_enqueue_script( 'walser-flexmenu', get_template_directory_uri() . '/js/flexmenu.js', array( 'jquery' ), '1.4.2', true );

	wp_enqueue_script( 'walser-swipebox', get_template_directory_uri() . '/js/swipebox.js', array( 'jquery' ), '1.4.4', true );

	wp_enqueue_script( 'walser-call', get_template_directory_uri() . '/js/call.js', array( 'jquery' ), '1.0', true );

}

add_action( 'wp_enqueue_scripts', 'walser_theme_styles_scripts' );

/**
 * Allow to use Shortcodes in Text Widgets.
 */
add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );

/**
 * Custom comments view.
 */
function walser_comment( $comment, $args, $depth ) {
?>

	<li <?php comment_class() ?> id="comment-<?php comment_ID() ?>">
		<div id ="div-comment-<?php comment_ID() ?>" class="comment-section clearfix">
			<div class="col-avatar">
				<figure class="comment-avatar">
					<?php echo get_avatar( $comment, 80 ) ?>
				</figure>
			</div>
			<div class="comment-body" role="complementary">
				<header class="comment-meta">
					<div clas="comment-meta-top">
						<div class="comment-author vcard">
							<?php comment_author_link() ?>
							<?php global $post; if ( $comment->user_id === $post->post_author ) { ?>
							<span class="small"><?php esc_html_e( 'Post author' , 'walser' ) ?></span>
							<?php } ?>
						</div>
						<time class="comment-date comment-metadata" datetime="<?php comment_time() ?>">
							<span><?php comment_date();?>,</span>
							<a class="comment-time comment-link" href="<?php comment_link() ?>"><?php comment_time() ?></a>
						</time>
					</div>
				</header>
				<div class="comment-content tc-content-inner">
					<?php comment_text() ?>
				</div>
				<?php comment_reply_link( array_merge( $args, array(
					'depth'     => $depth,
					'max_depth' => $args['max_depth'],
					'before'    => '<div class="comment-reply">',
					'after'     => '</div>',
				) ) );
				?>
			</div>
		</div>
	</li>
<?php }

/**
 * Places the comments form to right place for comment replying.
 */
function walser_theme_queue_js() {
	if ( ( ! is_admin()) && is_singular() && comments_open() && get_option( 'thread_comments' ) )
	wp_enqueue_script( 'comment-reply' );
}
add_action( 'wp_print_scripts', 'walser_theme_queue_js' );

/**
 * Set default link type to "file" for image galleries.
 */
function walser_gallery_default( $attr ) {
	$attr['link'] = 'file';
	return $attr;
}
add_filter( 'shortcode_atts_gallery', 'walser_gallery_default' );

/**
 * Hide posts navigation screen reader text.
 */
function walser_hide_navigation_text( $template, $class ) {
	return '
	<nav class="navigation %1$s">
		<div class="nav-links">%3$s</div>
	</nav>
	';
}
add_filter( 'navigation_markup_template', 'walser_hide_navigation_text', 10, 2 );

/**
 * Show post views. (Source: https://wp-kama.ru/id_55/schitaem-kolichestvo-posescheniy-stranits-na-wordpress.html).
 */
function walser_postviews() {
	$meta_key     = 'walserviews';
	$who_count    = 0; // 0 - all visitors; 1 - guests; 2 - registered users.
	$exclude_bots = 0; // 0 - no; 1 - yes.

global $user_ID, $post;
	if( is_singular() ) {
		$id = (int)$post->ID;
		static $post_views = false;
		if( $post_views ) return true;
		$post_views = (int)get_post_meta( $id, $meta_key, true );
		$should_count = false;
		switch( (int)$who_count ) {
			case 0: $should_count = true;
				break;
			case 1:
				if( (int)$user_ID == 0 )
					$should_count = true;
				break;
			case 2:
				if( (int)$user_ID > 0 )
					$should_count = true;
				break;
		}
		if( (int)$exclude_bots==1 && $should_count ) {

			if ( isset( $_SERVER[ 'HTTP_USER_AGENT' ] ) ) {
     			$useragent = intval( $_SERVER[ 'HTTP_USER_AGENT' ] );
			}

			$notbot = "Mozilla|Opera"; // browsers to count.
			$bot = "Bot/|robot|Slurp/|yahoo"; // bots to count.
			if ( !preg_match("/$notbot/i", $useragent ) || preg_match( "!$bot!i", $useragent ) )
				$should_count = false;
		}

		if( $should_count )
			if( !update_post_meta( $id, $meta_key, ( $post_views+1 ) ) ) add_post_meta( $id, $meta_key, 1, true );
	}
	return true;
}
add_action('wp_head', 'walser_postviews');

?>