<?php
/**
 * The template for displaying the header
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Walser
 * @since 1.0
 */

?><!DOCTYPE html>
<!--[if lt IE 8]> <html <?php language_attributes(); ?> class="no-js lt-ie8"> <![endif]-->
<!--[if gte IE 8]><!--> <html <?php language_attributes(); ?> class="no-js"> <!--<![endif]-->

<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>"/>
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width,minimum-scale=1,initial-scale=1">

	<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
	<div class="wrapper">

		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'walser' ); ?></a>

		<!-- Site header -->
		<header id="header" class="siteHeader overlay">
			<div class="layout_main">
				<div class="row">

					<!-- Site logo or name -->
					<div class="col headerLogo">
						<div class="siteLogo">
							<?php if ( has_custom_logo() ) {
								// Site logo.
								the_custom_logo();
							} else {
								// Site name.
								$sitename = get_bloginfo( 'name', 'display' );
									if ( $sitename || is_customize_preview() ) : ?>
										<a class="logo" href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php esc_html( bloginfo( 'name' ) ); ?></a>
									<?php endif;
							} ?>
						</div>
					</div>

					<!-- Navigation panel -->
					<div class="col headerNav">
						<nav class="navbar navbar-main" aria-label="<?php esc_attr_e( 'Menu', 'walser' ); ?>">
							<?php if ( has_nav_menu( 'primary' ) ) :
							wp_nav_menu( array(
								'theme_location' => 'primary',
								'container'      => false,
								'menu_class'     => 'navi',
								'menu_id'        => 'mainNavbar',
								'depth'          => 1, // No sub-menu items for view, only parent menu items are shown.
								) );
							endif; ?>
						</nav>
					</div>

					<!-- Search -->
					<div class="col headerTool">
						<div class="headerSearch">
							<div class="search-t">
								<span id="walser-s" data-component="modal" data-target="walser-search" role="button">
									<?php esc_html_e( 'Search', 'walser' ); ?>
								</span>
							</div>
							<div class="search-i"></div>
						</div>
						<div>
							<span class="close-menu" data-component="overlay" data-target="header" data-toggle="close" role="button" onclick="hideMobMenu()">&times;</span>
						</div>
					</div>

				</div>
			</div>
		</header>

		<main id="main" class="site-main">

			<!-- Mobile Navigation panel -->
			<nav id="mobNavbar" class="navbar mobNavbar" data-component="fixedNav" aria-label="<?php esc_attr_e( 'Menu', 'walser' ); ?>">

				<!-- Mobile Site logo -->
				<div class="navbarLogo">
					<span id="walser-menu" class="logo" data-component="overlay" data-target="header" data-toggle="open" role="button" tabindex="1" onclick="showMobMenu()"><?php echo esc_html( get_bloginfo( 'name' ) ); ?></span>
				</div>

				<div class="navbarSearch">
					<span id="walser-s-mobile" data-component="modal" data-target="walser-search" class="mob-search btn-search" role="button">
						<?php esc_html_e( 'Search', 'walser' ); ?>
					</span>
				</div>

			</nav>