<?php
/**
 * The template part for displaying single posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Walser
 * @since 1.0.0
 */

?>

<div id="post-header-<?php the_ID(); ?>" <?php post_class( 'col post-preview format-wide' ); ?>>

	<!-- Post thumbnail -->
	<div class="post-img">
		<?php if ( has_post_thumbnail() ) {
			the_post_thumbnail( 'walser-max-thumb' );
		} else {
			echo '<img class="no-post-image" src="' . esc_url( get_template_directory_uri() ) . '/images/none.png" alt="' . esc_attr( get_the_title() ) . '" >';
		} ?>
	</div>

	<!-- Post meta -->
	<div class="post-entry">

		<!-- Post categories -->
		<div class="entry-header row">
			<div class="post-cats">
				<?php $categories = get_the_category();
					if ( $categories ) {
						foreach ( $categories as $category ) {
							echo  '<a href="' . esc_html( get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a> ';
					}
				}
				?>
			</div>
		</div>

		<!-- Post format icon -->
		<div class="post-format">
			<?php if ( has_post_format() ) { ?>
				<a href="<?php echo esc_url( get_post_format_link( esc_html( get_post_format() ) ) ); ?>" title="<?php esc_attr_e( 'See all posts of this format', 'walser' ); ?>">
					<span class="format-icon"></span>
				</a>
			<?php } else { ?>
				<span class="format-icon"></span>
			<?php } ?>
		</div>

		<!-- Post title -->
		<div class="entry-content">
			<?php $walser_ttl = get_the_title(); if ( $walser_ttl !== '' ) { ?>
				<h1 class="h1"><?php the_title(); ?></h1>
			<?php } else { ?>
				<h1 class="h1 no-title"><?php esc_html_e( 'No title', 'walser' ); ?></h1>
			<?php } ?>
		</div>

		<!-- Post author and date of publication -->
		<div class="entry-footer">

			<div class="entry-meta">
				<div class="entry-author"><i class="fa fa-user" aria-hidden="true"></i> <?php echo esc_html( get_the_author() ); ?></div>
				<div class="entry-date"><i class="fa fa-calendar-alt" aria-hidden="true"></i> <?php echo esc_html( get_the_date() ); ?></div>
				<div class="entry-views"><i class="fa fa-eye" aria-hidden="true"></i> <?php echo esc_html( get_post_meta ( $post->ID, 'walserviews', true ) ); ?></div>
				<div class="entry-comments"><i class="fa fa-comment" aria-hidden="true"></i> <?php echo '<a href="' . esc_url( get_comments_link() ) .'">'. esc_html( $post->comment_count ) .'</a>'; ?></div>
			</div>

			<!-- Post management -->
			<?php global $current_user;
			wp_get_current_user();
			if ( is_user_logged_in() && $current_user->ID == $post->post_author ) { ?>
				<div class="entry-cog">
					<div class="cogs">
						<a class="cog-edit" href="<?php echo esc_url( get_edit_post_link() ); ?>"><?php esc_html_e( 'Edit', 'walser' ); ?></a><br>
						<a class="cog-del" href="<?php echo esc_url( get_delete_post_link() ); ?>"><?php esc_html_e( 'Delete', 'walser' ); ?></a>
					</div>
					<span class="cog"><i class="fa fa-cog" aria-hidden="true"></i></span>
				</div>
			<?php } ?>

		</div>
	</div>

</div>

<div id="main-content" class="container">
	<div class="post-content col">

		<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>

			<!-- Post content -->
			<?php if ( '' !== get_post()->post_content ) { ?>
			<div class="post-body">
				<?php the_content(); ?>
			</div>
			<div class="clear"></div>
			<?php } ?>

			<!-- Post pagination -->
			<?php wp_link_pages(
				array(
					'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'walser' ),
					'after' => '</div>',
				)
			); ?>

			<!-- Post tags -->
			<?php if ( has_tag() ) { ?>
			<div class="post-tags">
				<?php the_tags( '', ' ' ); ?>
			</div>
			<?php } ?>

			<!-- Comments -->
			<?php if ( comments_open() || get_comments_number() ) { ?>
			<div class="post-comments">
				<?php comments_template(); ?>
			</div>
			<?php } ?>

		</div>

		<!-- Include the related posts template part -->
		<?php get_template_part( 'template-parts/related-posts' ); ?>

	</div>

	<!-- Main Sidebar -->
	<aside class="sidebar-content col">
		<?php get_sidebar( 'sidebar' ); ?>
	</aside>

</div>